# CipError

CipError is a python package that contains the specification of the errors generated by the CIP applications.

CipError supports python 3+.

# Examples
-
## Install

> Under your virtualenv do:  

```
$ pip install ciperror
```

## Getting Started

All you have todo is import the package in your code and you will have access to the error classes definitions.

## Upload Package
```bash
$ python3 setup.py sdist upload
```
## Upload Package using twine
> Required install twine

```bash
$ python3 setup.py bdist_wheel
$ twine upload dist/ciperror-X.X.XX-py3-none-any.whl
```

## Release History  
* 1.0.0
  * Initial structure of the error classes.
* 1.0.3
  * Including Encoding Factory Errors
* 1.0.4
  * Including Gateway Redirect Timeout error for BFF
* 1.0.5
  * Including GeneralUnexpectedError class
* 1.0.6
  * Including JobDataService errors
* 1.0.8
  * Including JobNotFound errors    
* 1.0.9
  * Including Error for File Copy API request.
* 1.0.10
  * Including Orchestrator Notification errors.
* 1.0.13
  * Including Status, Orchestrator, Check File and Release Notes services request errors.
* 1.0.14
  * Including Release Notes service general unexpected error.
* 1.0.15
  * Including GenericServiceRequestError class
* 1.0.16
  * Including Transcoder and Elemental errors classes
* 1.0.17
  * Including Ladder and File Copy errors classes  
* 1.0.18
  * Add new Job error for the Elemental error class
* 1.0.20
  * Add new Database error for duplicate entries.
* 1.0.21
  * Add new Elemental transcoding error.
* 1.0.22
  * Add FTP General errors
* 1.0.23
  * Add new File Copy Checksum error and Bad File error
* 1.0.24
  * Add new TranscoderFinishJobError
* 1.0.25
  * Add new UploadFileError
* 1.0.26
  * Add new CallBackNotificationError
* 1.0.27
  * Add new NotificationError
* 1.0.28
  * Add new EFResponseOfflineError for EF API response error
* 1.0.29
  * Add new EFUnprocessableEntityError for EF API Unprocessable Entity error
* 1.0.30
  * Add new Connection errors: RedisConnectionError and SMTPConnectionError
* 1.0.31
  * Add step BaseCipError
* 1.0.32
  * Add new EmailServiceRequestError
* 1.0.33
  * Fix EmailServiceRequestError init param
1.0.34
  * Add new EmailServiceOfflineError
1.0.35
  * Add new MAMIntegrationServiceRequestError, MAMIntegrationServiceOfflineError 
1.0.36
  * Add new FTPServiceRequestError 
1.0.37
  * Add new NotificationURLOfflineError
1.0.40
  * Add new ClientCredentialsTokenError
1.0.41
  * Add new XmlPebbleParserError
1.0.42
  * Add new Unauthorized error
1.0.42
  * Add new PermissionDenied error  

# Mensagens de erro

### Categorias de erros

*  **GAE**  - General Api Errors (Erros gerais em Apis);
*  **GEE**  - General Expected Errors (Erros gerais em qualquer serviço);
*  **GUE**  - General Unexpected Errors (Erros inexperados e desconhecidos);
*  **DBE**  - Database Errors (Erros envolvendo banco de dados);
*  **IOE**  - Input Output Errors (Erros de entrada e saída);
*  **UXE**  - General View Errors (Erros gerais envolvendo as telas);
*  **GFS**  - General File System Errors (Erros gerais envolvendo arquivos);
*  **EFE**  - Encoding Factory Errors (Erros envolvendo a integração com a EF);
*  **JDS**  - Job Data Service Errors (Erros envolvendo o serviço de Metadados);
*  **TRE**  - Transcoder Service Errors (Erros envolvendo o serviço de orquestração de transcoding);
*  **ELE**  - Elemental Service Errors (Erros envolvendo o agente de integracao com o Elemental);
*  **FLC**  - Elemental Service Errors (Erros envolvendo o agente de integracao com o Elemental);
*  **LAD**  - Elemental Service Errors (Erros envolvendo o agente de integracao com o Elemental);
*  **FTP**  - FTP Service Errors (Erros envolvendo o serviço de FTP)
*  **CBE**  - Callback Errors (Error envolvendo o callback do serviço)
*  **CONN** - Connection Errors

### Parametros para as mensagens
*  ***message*** - Parametro para a mensagem gerada na ocorrência do erro;
*  ***param*** - Parametro auxiliar normalmente contendo o identificador do registro;

## GAE  

###### *General Api Errors (Error gerais em Apis)*

| Código | Classe | Mensagem no Log | Status Code | Mensagem Amigável |
|:------:|:------:|-----------------|:-----------:|-------------------|
| GAE001 | OrchestratorOfflineError | "orquestrador offline: " + <`message`> |500| o orquestrador encontra-se indisponível |
| GAE002 | KpiOfflineError| "JobData offline: " + <`message`> |500| o JobData encontra-se indisponível |          
| GAE003 | MonitoringStatusOfflineError | "MonitoringStatus offline: " + <`message`> |500| o MonitoringStatus encontra-se indisponível |
| GAE004 | JobDataOfflineError | "Kpi offline: " + <`message`> |500| o Kpi encontra-se indisponível |          
| GAE005 | Ingest4KIngestProcessError | "Erro no processo de ingest: " + <`message`> |500| Erro no processo de ingest. |
| GAE006 | KpiApiResponseError | "Erro ao consumir a API do KPI: " + <`message`> |500| Erro ao consumir a API do KPI. |
| GAE007 | JobDataApiRequestError | "Erro no request para a Job Data API: " + <`message`> |500| Erro no request para a Job Data API. |
| GAE008 | JobDataApiAddJobError | "Erro ao cadastrar job {0}: ".format(param) + <`message`> |500| Erro ao cadastrar job {0}.".format(param) |
| GAE009 | JobDataApiUpdateProfileError | "Erro no update do profile: " + <`message`> |422| Erro no update do profile. |
| GAE010 | JobDataApiUpdateFileError | "Erro ao atualizar o arquivo: " + <`message`> |500| Erro ao atualizar o arquivo. |
| GAE011 | JobDataApiDeliveryFileError | "Erro ao entregar o arquivo: " + <`message`> |500| Erro ao entregar o arquivo. |
| GAE012 | MonitoringApiRequestError | "Erro no request para o Monitoring API: " + <`message`> |500| Erro no request para o Monitoring API. |
| GAE013 | PublisherApiRequestError | "Erro no request para o PublisherAPI: " + <`message`> |500| Erro no request para o publicador na EF. |
| GAE014 | EFApiRequestError | "Erro no request para o EF API: " + <`message`> |500| Erro no request para o EF API. |
| GAE015 | EFApiDeliveryError | "Erro na entrega do profile para EF: " + <`message`> |500| Erro na entrega do profile para EF. |
| GAE016 | EFApiPublishError | "Erro na publicacao do profile na EF: " + <`message`> |500| Erro na publicação do profile na EF. |
| GAE017 | JobDataApiUpdateStatusjobError | "Erro no update de job enviado ao Job Data API: URL: " + <`message`> |500| Erro no update de job enviado ao Job Data API. |
| GAE018 | OrquestratorApiProcessamentoMensagensError | "Erro no loop de processamento de mensagens: " + <`message`> |500| Erro no loop de processamento de mensagens. |
| GAE019 | MonitoringApiUpdateStatusjobError | "Erro no update de job enviado ao Monitoring API: {} " + <`message`> |500| Erro no update de job enviado ao Monitoring API. |
| GAE020 | FileCopyApiRequestError | "Erro no request para a File Copy API: {}" + <`message`> |500| Erro no request para a File Copy API. |
| GAE021 | OrchestratorApiNotificationError | "Erro ao notificar o OrchestratorApi: {} " + <`message`> |500| Erro ao notificar o OrchestratorApi. |
| GAE022 | StatusServiceRequestError | "Erro ao notificar o Status Service: {} " + <`message`> |500| Erro ao notificar o Status Service. |
| GAE023 | OrchestratorServiceRequestError | "Erro ao notificar o Orchestrator Service: {} " + <`message`> |500| Erro ao notificar o Orchestrator Service. |
| GAE024 | CheckFileServiceRequestError | "Erro ao notificar o Check File Service: {} " + <`message`> |500| Erro ao notificar o Check File Service. |
| GAE025 | ReleaseNotesServiceRequestError | "Erro ao notificar o Release Notes Service: {} " + <`message`> |500| Erro ao notificar o Release Notes Service. |
| GAE026 | GenericServiceRequestError | "Erro no request para o" + <`service_name`>: + <`message`> |500| Erro no request para o " + <`service_name`> |
| GAE0027 | EmailServiceRequestError | "Erro no request para o Email Service: {}" <`message`> |500| Erro no request para o Email Service. |
| GAE0028 | EmailServiceOfflineError | "Email Service offline: {}" + <`message`> |500| Email Service encontra-se indisponível |
| GAE029 | MAMIntegrationServiceOfflineError | "MAM Integration Service offline: {}" + <`message`> |500| MAM Integration Service encontra-se indisponível. |
| GAE030 | MAMIntegrationServiceRequestError | "Erro no request para o MAM Integration Service: {}" + <`message`> |500| Erro no request para o MAM Integration Service. |
| GAE031 | FTPServiceServiceRequestError | "Erro no request para o FTP Service: {}" + <`message`> |500| Erro no request para o FTP Service. |
| GAE032 | NotificationURLOfflineError | "Erro no envio da notificação para a url: {} <`message`> |500| Serviço encontra-se indisponível. |
| GAE033 | ClientCredentialsTokenError | "Erro ao gerar token, client id e/ou client secret estão errados: {}" +  <`message`> |401| Erro ao enviar o id e secret do cliente para gerar o token. |
## GEE  

###### *General Expected Errors (Erros gerais em qualquer serviço)*
| Código | Classe | Mensagem no Log | Status Code | Mensagem Amigável |
|:------:|:------:|-----------------|:-----------:|-------------------|
| GEE001 | InvalidProfileError | "Profile name inválido: " + <`message`> |422| profile name inválido |          
| GEE002 | ProfileCancelledError | "profile cancelado: " + <`message`> |422| Houve uma tentativa de atualizar um profile que ja foi cancelado. |
| GEE003 | NoProfileReadyForReviewError | "Sem profiles com ready_for_review: " + <`message`> |409| Não há profiles prontos para revisão. |  
| GEE004 | JobIdAlreadyExist | "Já existe um job com o id: {0}." + <`message`> |400| Já existe um job com o id: {0} |  
| GEE005 | GatewayRedirectTimeoutError | "Tempo de requisição para a url [{0}] esgotado." + <`message`> |504| Erro de comunicação interna |
| GEE006 | JobNotFoundError | "Job: {} não encontrado." + <`job_id`> |404| Não foi possível localizar as informações detalhadas desta mídia. |  
| GEE007 | Unauthorized | "Token de acesso inválida. Access-token: {}" + <`access_token`> |401| Acesso não autorizado. Token inválida ou inexistente. |
| GEE008 | PermissionDenied | "Permissão negada" |403| Permissão negada. Usuario sem permissões para acessar o recurso. |  



## GUE  

###### *General Unexpected Errors (Erros inesperados e desconhecidos)*
| Código | Classe | Mensagem no Log | Status Code | Mensagem Amigável |
|:------:|:------:|-----------------|:-----------:|-------------------|
| GUE000 | GeneralUnexpectedError | "Erro inesperado no <`service_name`>: " + <`message`> |500| Erro inesperado no <`service_name`>. |
| GUE001 | JobDataApiGeneralUnexpectedError | "Erro inesperado no JobDataAPI: " + <`message`> |500| Erro desconhecido no JobDataAPI. |
| GUE002 | Ingest4KGeneralUnexpectedError | "Erro inesperado no Ingest 4K: " + <`message`> |500| Erro desconhecido no Ingest 4K. |
| GUE003 | EFApiGeneralUnexpectedError | "Erro inesperado no EF API: " + <`message`> |500| Erro desconhecido no serviço de integração com a EF. |
| GUE004 | OrquestratorGeneralUnexpectedError | "Erro inesperado no Orchestrator: " + <`message`> |500| Erro desconhecido no Orchestrador. |
| GUE005 | CheckFileGeneralUnexpectedError | "Erro inesperado no CheckFile: " + <`message`> |500| Erro desconhecido no Serviço de verificação de arquivos. |
| GUE006 | AppPCAGeneralUnexpectedError | "Erro inesperado no AppPCA: " + <`message`> |500| Erro desconhecido no serviço de integração com a EF. |
| GUE007 | MonitoringGeneralUnexpectedError | "Erro inesperado na Monitoracao: " + <`message`> |500| Erro desconhecido no serviço de monitoração em tempo real. |
| GUE008 | BFFGeneralUnexpectedError | "Erro inesperado no BFF: " + <`message`> |500| Erro desconhecido no serviço de integração entre a página e os serviços de Media Delivery. |
| GUE009 | StatusServiceUnexpectedError | "Erro inesperado no Status Service: " + <`message`> |500| Erro desconhecido no serviço de status. |
| GUE010 | ReleaseNotesServiceGeneralUnexpectedError | "Erro inesperado no BFF: " + <`message`> |500| Erro desconhecido no serviço de release notes. |


## DBE

###### *Database Errors (Erros envolvendo banco de dados)*
| Código | Classe | Mensagem no Log | Status Code | Mensagem Amigável |
|:------:|:------:|-----------------|:-----------:|-------------------|
| DBE001 | DatabaseServerConnectionError |  "Sem conexao com o banco de dados. " + <`message`> |504| Sem conexão com o banco de dados. |
| DBE002 | DatabaseTimeoutError | "TimeOut, tempo de conexao maior que o permitido: " + <`message`> |408| Problemas na conexão com o banco de dados. |
| DBE003 | MongoInvalidURIError | "URI invalida, a uri deve conter **mongodb://** ou **mongodb+srv://**. |400| Sem conexão com o banco de dados. |
| DBE004 | DatabaseNetworkTimeoutError | "A conexão aberta excedeu o **socketTimeout**: " + <`message`> |408| Sem conexão com o banco de dados. |
| DBE005 | DatabaseWriteError | "Erro durante a escrita no banco de dados: " + <`message`> |500| Sem conexão com o banco de dados. |
| DBE006 | DatabaseAckError | "Erro ACK message: " + <`message`> |500| Sem conexão com o banco de dados. |
| DBE007 | DatabaseNoReponseError | "Sem resposta do banco de dados: " + <`message`> |500| Sem conexão com o banco de dados. |
| DBE008 | DatabaseDuplicateEntryError | "Entrada duplicada não permitida: " + <`message`> |409| Não é possível cadastrar duas entradas iguais no banco. |

## IOE

###### *Input Output Errors (Erros de entrada e saída)*
| Código | Classe | Mensagem no Log | Status Code | Mensagem Amigável |
|:------:|:------:|-----------------|:-----------:|-------------------|
| IOE001 | InvalidInputError | "Entrada inválida: " + <`message`> |422| Os dados inseridos são inválidos para essa operação. |  
| IOE002 | InvalidKpiError | "Id do kpi invalido: " + <`message`> |422| D do sistema KPI dos Estúdios Globo inválido. |  
| IOE003 | KpiExistError | "Ja existe um job com esse ID(kpi_metadata.id:" + <`message`> |422| Erro ao cadastrar um novo job de entrega. |  
| IOE004 | InvalidProfileError | "Nome do profile invalido: " + <`message`> |422| Nome do profile inválido. |  
| IOE005 | EfidExistError | "Ja existe um ef_id para esse job: " + <`message`> |422| Ja existe um ID da EF para esse job de entrega. |    
| IOE006 | StatusError | "Status não pode ser menor que o atual: " + <`message`> |422| Erro na atualizacão do status. |  
| IOE007 | StatusReadyForReviewError | "Sem profiles com o status = ready_for_review: " + <`message`> |422| Não existem profiles prontos para revisão. |  
| IOE008 | StatusCancelledError | "este profile ja foi cancelado: " + <`message`> |422| Profile já cancelado. |
| IOE009 | DateTimeStartError | "O DateTime inicial ja foi cadastrado: " + <`message`> |422| Já existe data cadastrada. |  
| IOE010 | DateTimeFinishError | "O DateTime final ja foi cadastrado: " + <`message`> |422| Já existe data cadastrada. |
| IOE011 | DateTimeSaveError | "data inicial < que data final: " + <`message`> |422| A data inicial precisa ser menor que a data final.) |
| IOE012 | StatusUpdateError | "Erro ao atualizar o status: " + <`message`> |422| Status atual não pode ser atualizado.|
| IOE013 | EfRequiredError | "ef_id' é uma propriedade obrigatória: " + <`message`> |422| O ID da EF é obrigatório.|
| IOE014 | EfIdIntError | "ef id deve ser inteiro: " + <`message`> |422| EF ID deve ser um número inteiro. |  
| IOE015 | DateValidationError | "Problema no preenchimento da Data: " + <`message`> |422| Problema no preenchimento da data. | 
| IOE016 | XmlPebbleParserError | Erro ao parsear o XML vindo da Pebble: " + <`message`> |404| Problema ao ler o arquivo XML vindo da Pebble. |   

## UXE

###### *General View Errors (Erros gerais envolvendo as telas)*
| Código | Mensagem no Log | Status Code | Mensagem Amigável |
|:------:|-----------------|:-----------:|-------------------|


## GFS

###### *General File System Errors (Erros gerais envolvendo arquivos)*
| Código | Classe | Mensagem no Log | Status Code | Mensagem Amigável |
|:------:|:------:|-----------------|:-----------:|-------------------|
| GFS001 | StorageUnreacheableError | "Storage indisponível. " + <`message`> |500| O storage utilizado pelo sistema está indisponível. |  
| GFS002 | FileNotFoundError | "Arquivo não encontrado: " + <`message`> |404| Arquivo não encontrado. |  
| GFS003 | PathNotFoundError | "Diretório inválido ou inexistente: " + <`message`> |404| Diretório inválido ou inexistente. |
| GFS004 | PermissionDeniedError | "Permissão negada no storage: " + <`message`> |401| Usuário ou aplicação não tem permissão de acesso ao storage. |
| GFS005 | NotEnoughSpaceError | "O storage não possui espaço suficiente: " + <`message`> |507| O storage não possui espaço suficiente para a operação. |      



## EFE

###### *Encoding Factory Errors (Erros envolvendo a integração com a EF)*
| Código | Classe | Mensagem no Log | Status Code | Mensagem Amigável |
|:------:|:------:|-----------------|:-----------:|-------------------|
| EFE001 | EFGeneralUnexpectedError | "Erro inexperado: " + <`message`> |500| Erro na integração com a EF. |  
| EFE002 | PublishRequestError | "Erro no post de publish request: " + <`message`> |500| Erro ao criar um rascunho na EF. |  
| EFE003 | DraftNotFoundError | "UUID " + <`uuid`> + " não encontrado:: " + <`message`> |404| Não existe rascunho na EF para o código informado. |
| EFE004 | ProgramNotFoundError | "program_id " + <`program_id`> + " não encontrado:" + <`message`> |404| Não existe programa na EF para o código informado. |
| EFE005 | MediaNotFoundError | "ef_id + <`ef_id`> + não encontrado: " + <`message`> |404| Não existe mídia na EF para o código informado. |      
| EFE006 | ProfileError | "Erro/rejeição de profile: " + <`message`> |500| Ocorreu um erro ao criar um profile de vídeo na EF. |
| EFE007 | CreateMediaError | "Erro de publish/create na EF: " + <`message`> |500| Erro de publicação na EF. |
| EFE008 | ReplaceMediaError | "Erro no replace da mídia: + <`ef_id`> +  na EF: " + <`message`> |500| Erro ao regerar mídia na EF. |
| EFE009 | EFResponseOfflineError | "Sem resposta da API da EF: " + <`message`> |500| Sem resposta da API da EF. |
| EFE0010 | EFUnprocessableEntityError | "Erro no envio dos profiles a EF: " + <`message`> |422| Erro no envio dos profiles a EF. |

## JDS

###### *Job Data Service Errors (Erros envolvendo o serviço de Metadados)*
| Código | Classe | Mensagem no Log | Status Code | Mensagem Amigável |
|:------:|:------:|-----------------|:-----------:|-------------------|
| JDS001 | JobDataServicelUnexpectedError | "Erro inesperado no JobDataService: " + <`message`> |500| Erro desconhecido no serviço de metadados de job. |  
| JDS002 | JobDataServiceNotFoundError | "Job ID não encontrado: " + <`message`> |404| Job não encontrado. |  

## TRE

###### *Transcoder Service Errors (Erros envolvendo o serviço de orquestração de transcoding)*
| Código | Classe | Mensagem no Log | Status Code | Mensagem Amigável |
|:------:|:------:|-----------------|:-----------:|-------------------|
| TRE001 | TranscoderServiceRequestError | "Erro no request para o Transcoder Service: " + <`message`> |500| Erro no request para o Transcoder Service. |  
| TRE002 | TranscoderJobNotFoundError | "Job de transcoder não encontrado: " + <`message`> |404| Job de transcoder não encontrado. |  
| TRE003 | TranscoderFinishJobError | "Erro durante a finalização do job de transcoder.: " + <`message`> |500| Erro durante a finalização do job de transcoder. |  

## ELE

###### *Elemental Service Errors (Erros envolvendo o agente de integracao com o Elemental)*
| Código | Classe | Mensagem no Log | Status Code | Mensagem Amigável |
|:------:|:------:|-----------------|:-----------:|-------------------|
| ELE001 | ElementalServiceRequestError | "Erro no request para o Elemental Service: " + <`message`> |500| Erro no request para o Elemental Service. |  
| ELE002 | CreateElementalJobRequestError | "Erro no post de criar job: " + <`message`> |500| Erro ao criar um job no elemental. |  
| ELE003 | ElementalTranscodingError | "rro no processo de transcoding do elemental: " + <`message`> |500| Erro no processo de transcoding. |  


## FLC

###### *File Copy Service Errors (Erros envolvendo o agente de integracao com o File Copy Service)*
| Código | Classe | Mensagem no Log | Status Code | Mensagem Amigável |
|:------:|:------:|-----------------|:-----------:|-------------------|
| FLC001 | FileCopyServiceRequestError | "Erro no request para o File Copy Service: " + <`message`> |500| Erro no request para o File Copy Service. |  
| FLC002 | FileCopyBadChecksumError | "Erro na verificação do checksum: " + <`message`> |500| Erro de integridade de arquivo. |  
| FLC003 | FileCopyBadFileError | "Arquivo com falha de integridade: " + <`message`> |500| Erro de integridade de arquivo. |  


## LAD

###### *File Copy Service Errors (Erros envolvendo o agente de integracao com o Ladder Service)*
| Código | Classe | Mensagem no Log | Status Code | Mensagem Amigável |
|:------:|:------:|-----------------|:-----------:|-------------------|
| LAD001 | LadderServiceRequestError | "Erro no request para o Ladder Service: " + <`message`> |500| Erro no request para o Ladder Service. |
| LAD002 | LadderServiceNotFoundError | "Ladder não encontrada: " + <`message`> |404| Ladder não encontrada. |   

## FTP

###### *FTP Service Errors (Erros envolvendo o serviço de FTP)*
| Código | Classe | Mensagem no Log | Status Code | Mensagem Amigável |
|:------:|:------:|-----------------|:-----------:|-------------------|
| FTP001 | UploadFileError | "Erro ao realizar upload do arquivo na EF: " + <`message`> |404| Erro ao realizar upload do arquivo |   


## CBE

###### *Callback Errors (Erros envolvendo o callback dos serviços)*
| Código | Classe | Mensagem no Log | Status Code | Mensagem Amigável |
|:------:|:------:|-----------------|:-----------:|-------------------|
| CBE001 | CallBackNotificationError | Erro ao realizar callback da requisição para o serviço: " + <`service`> + " - message: " + <`message`>  |500| Erro ao notificar serviço + <`service`>  | 
| CBE002 | NotificationError | Erro ao enviar notificação para o serviço: " + <`service`> + " - message: " + <`message`>  |500| Erro ao enviar notificação para o serviço + <`service`> | 

## CONN

###### *Connection Errors (Erros de conexão com servidores remotos)*
| Código | Classe | Mensagem no Log | Status Code | Mensagem Amigável |
|:------:|:------:|-----------------|:-----------:|-------------------|
| CONN001 | RedisConnectionError | Erro de conexão com o Redis: MESSAGE: + <`message`>  | 
| CONN002 | SMTPConnectionError | Erro de conexão com o servidor SMTP: MESSAGE:  + <`message`>  | 
| CONN003 | FTPConnectionError | Erro de conexão com o servidor de FTP da PEBBLE: MESSAGE:  + <`message`>  | 